@@ -19,19 +19,19 @@ class TestCasesOrdersAccountant(unittest.TestCase):
         self.accountant = Accountant(ledger_host='http://0.0.0.0:3000', bank_account=bank_account)
 
     def test_block_for_order(self):
-        order_id = "605"
+        order_id = "711"
         order_type = 'limit'
         currency = 'inr'
-        value = '100'
+        value = '103'
         operation = self.accountant.block_for_order(order_id, order_type, currency, value)
         self.assertIn("status", operation)
         self.assertEqual(operation['status'], 'APPLIED')
 
     def test_update_order_fill_status(self):
-        order_id = "605"
+        order_id = "711"
         from_currency = 'inr'
-        to_currency = 'btc'
-        from_amount = '40'
+        to_currency = 'eth'
+        from_amount = '100'
         to_amount = '40'
         memo = '102'
         order_type = 'limit'
@@ -158,6 +158,9 @@ class TestCasesOrdersAccountant(unittest.TestCase):
         self.assertIn("status", operation)
         self.assertEqual(operation['status'], 'APPLIED')
 
+    def test_get_book(self):
+        self.accountant.get_book()
+
 
 if __name__ == '__main__':
     unittest.main()
